BufferPool

Struct BufferPool 

pub struct BufferPool { /* private fields */ }
A buffer pool.

This type by itself does nothing, and should only be used by *Managed ops.

Implementations

Source

impl BufferPool

pub fn pop(&self) -> Result<BufferRef, Error>

Available on crate feature runtime only.

Pop an available buffer from the pool with given capacity.

This operation is not supported on io-uring driver and will always return Unsupported.

pub fn take(&self, buffer_id: u16) -> Result<Option<BufferRef>, Error>

Available on crate feature runtime only.

Take the indicated buffer from the pool.

Returns None if the buffer is not reset back yet or does not exist.

pub fn reset(&self, buffer_id: u16) -> Result<bool, Error>

Available on crate feature runtime only.

Reset the buffer_id so that it’s available for kernel to use, return whether a buffer has been reset.

This is the same as take(buffer_id) and immediately drop it.